@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v0.6.5");
+use version; our $VERSION = version->declare("v0.6.6");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -13,7 +13,7 @@ sub auto_install { $AUTO_INSTALL }
 1;
 __END__
 
-=for stopwords MINILLA
+=for stopwords MINILLA .mailmap
 
 =encoding utf8
 
@@ -230,6 +230,12 @@ Note that this feature is not officially documented in L<CPAN::Uploader>.
 
 =over 4
 
+=item How can I manage B<contributors> section?
+
+Minilla aggregates contributors list from C<< git log --format="%aN <%aE>" | sort | uniq >>.
+
+You can merge accounts by .mailmap file. See L<https://www.kernel.org/pub/software/scm/git/docs/git-shortlog.html>
+
 =item Why don't you provide plug-in support?
 
 If you want to pluggable thing, it's already exist dzil :P
